mriqc.workflows package — mriqc 0.8 documentation

# mriqc.workflows package

## Submodules

## mriqc.workflows.anatomical module

A QC workflow for anatomical MRI

`mriqc.workflows.anatomical.` `airmsk_wf`(name='AirMaskWorkflow', testing=False, ants_settings=None)

  Implements the Step 1 of [Mortamet2009].

`mriqc.workflows.anatomical.` `anat_qc_workflow`(name='MRIQC_Anat', settings=None)

  One-subject-one-session-one-run pipeline to extract the NR-IQMs from anatomical images

`mriqc.workflows.anatomical.` `combine_masks`(head_mask, artifact_msk, out_file=None)

  Computes an air mask from the head and artifact masks

`mriqc.workflows.anatomical.` `gradient_threshold`(in_file, thresh=1.0, out_file=None)

  Compute a threshold from the histogram of the magnitude gradient image

`mriqc.workflows.anatomical.` `headmsk_wf`(name='HeadMaskWorkflow')

  Computes a head mask as in [Mortamet2009].

`mriqc.workflows.anatomical.` `image_gradient`(in_file, compute_abs=True, out_file=None)

  Computes the magnitude gradient of an image using numpy

## mriqc.workflows.core module

The core module combines the existing workflows

`mriqc.workflows.core.` `ms_anat`(settings=None, subject_id=None, session_id=None, run_id=None)

  Multi-subject anatomical workflow wrapper

`mriqc.workflows.core.` `ms_func`(settings=None, subject_id=None, session_id=None, run_id=None)

  Multi-subject functional workflow wrapper

## mriqc.workflows.functional module

A QC workflow for fMRI data

`mriqc.workflows.functional.` `fmri_bmsk_workflow`(name='fMRIBrainMask', use_bet=False)

  Comute brain mask of an fmri dataset

`mriqc.workflows.functional.` `fmri_qc_workflow`(name='fMRIQC', settings=None)

  The fMRI qc workflow

`mriqc.workflows.functional.` `hmc_afni`(name='fMRI_HMC_afni', st_correct=False)

  A head motion correction (HMC) workflow for functional scans

`mriqc.workflows.functional.` `hmc_mcflirt`(name='fMRI_HMC_mcflirt')

  An HMC for functional scans using FSL MCFLIRT

## mriqc.workflows.utils module

Helper functions for the workflows

`mriqc.workflows.utils.` `fd_jenkinson`(in_file, rmax=80.0, out_file=None)

  Compute the FD [Jenkinson2002] on a 4D dataset, after AFNI-`3dvolreg` has been executed (generally a file named `*.affmat12.1D`).

  Parameters: | in_file (str) – path to epi file rmax (float) – the default radius (as in FSL) of a sphere represents the brain in which the angular displacements are projected. out_file (str) – a path for the output file with the FD
  Returns: | the output file with the FD, and the average FD along the time series
  Return type: | tuple(str, float)

  Note

  `infile` should have one 3dvolreg affine matrix in one row - NOT the motion parameters

  Note

  Acknowledgments

  We thank Steve Giavasis (@sgiavasis) and Krishna Somandepali for their original implementation of this code in the [QAP].

`mriqc.workflows.utils.` `fmri_getidx`(in_file, start_idx, stop_idx)

  Heuristics to set the start and stop indices of fMRI series

`mriqc.workflows.utils.` `fwhm_dict`(fwhm)

  Convert a list of FWHM into a dictionary

## Module contents